@@ -1,5 +1,3 @@
-SUBMERCADOS = ["SUDESTE", "SUL", "NORDESTE", "NORTE"]
-
 MAX_SERIES_SINTETICAS = 2000
 MAX_PATAMARES = 5
 NUM_CENARIOS = 2000
@@ -13,6 +11,7 @@ MAX_CORTES = MAX_ITERS * MAX_FORWARDS
 MAX_UHES = 330
 MAX_CONJUNTOS_MAQUINAS = 5
 MAX_UTES = 300
+MAX_UEES = 999
 MAX_RES = 100
 MAX_REES = 30
 MAX_LAG_ADTERM = 2
