@@ -99,6 +99,9 @@ from inewave.newave.modelos.dger import BlocoRestricaoLPPTurbinamentoMaximoREE
 from inewave.newave.modelos.dger import BlocoRestricaoLPPDefluenciaMaximaREE
 from inewave.newave.modelos.dger import BlocoRestricaoLPPTurbinamentoMaximoUHE
 from inewave.newave.modelos.dger import BlocoRestricaoLPPDefluenciaMaximaUHE
+from inewave.newave.modelos.dger import BlocoRestricoesEletricasEspeciais
+from inewave.newave.modelos.dger import BlocoFuncaoProducaoUHE
+from inewave.newave.modelos.dger import BlocoFCFPosEstudo
 
 
 class DGer(SectionFile):
@@ -206,6 +209,9 @@ class DGer(SectionFile):
         BlocoRestricaoLPPDefluenciaMaximaREE,
         BlocoRestricaoLPPTurbinamentoMaximoUHE,
         BlocoRestricaoLPPDefluenciaMaximaUHE,
+        BlocoRestricoesEletricasEspeciais,
+        BlocoFuncaoProducaoUHE,
+        BlocoFCFPosEstudo,
     ]
 
     def __init__(self, data=...) -> None:
@@ -2312,3 +2318,60 @@ class DGer(SectionFile):
         b = self.__bloco_por_tipo(BlocoRestricaoLPPDefluenciaMaximaUHE, 0)
         if b is not None:
             b.valor = dado
+
+    @property
+    def restricoes_eletricas_especiais(self) -> Optional[int]:
+        """
+        Configuração da linha número 98 do arquivo `dger.dat`.
+
+        :return: O valor do campo
+        :rtype: int | None
+        """
+        b = self.__bloco_por_tipo(BlocoRestricoesEletricasEspeciais, 0)
+        if b is not None:
+            return b.valor
+        return None
+
+    @restricoes_eletricas_especiais.setter
+    def restricoes_eletricas_especiais(self, dado: int):
+        b = self.__bloco_por_tipo(BlocoRestricoesEletricasEspeciais, 0)
+        if b is not None:
+            b.valor = dado
+
+    @property
+    def funcao_producao_uhe(self) -> Optional[int]:
+        """
+        Configuração da linha número 99 do arquivo `dger.dat`.
+
+        :return: O valor do campo
+        :rtype: int | None
+        """
+        b = self.__bloco_por_tipo(BlocoFuncaoProducaoUHE, 0)
+        if b is not None:
+            return b.valor
+        return None
+
+    @funcao_producao_uhe.setter
+    def funcao_producao_uhe(self, dado: int):
+        b = self.__bloco_por_tipo(BlocoFuncaoProducaoUHE, 0)
+        if b is not None:
+            b.valor = dado
+
+    @property
+    def fcf_pos_estudo(self) -> Optional[int]:
+        """
+        Configuração da linha número 100 do arquivo `dger.dat`.
+
+        :return: O valor do campo
+        :rtype: int | None
+        """
+        b = self.__bloco_por_tipo(BlocoFCFPosEstudo, 0)
+        if b is not None:
+            return b.valor
+        return None
+
+    @fcf_pos_estudo.setter
+    def fcf_pos_estudo(self, dado: int):
+        b = self.__bloco_por_tipo(BlocoFCFPosEstudo, 0)
+        if b is not None:
+            b.valor = dado
