@@ -6,6 +6,12 @@ MockRegistroEolicaHistorico = (
     "EOLICA-HISTORICO-VENTO; 1; 1979/01; 1979/02;    3.43; 1.0\n"
 )
 
+MockRegistroHistoricoVentoHorizonte = (
+    "VENTO-HIST-HORIZ  ; 1979/01     ; 2016/01\n"
+)
+
+MockRegistroHistoricoVento = "VENTO-HIST  ; 1           ; 1979/01     ; 1979/02   ;      4.05       ; 1.0\n"
+
 MockEolicaHistorico = [
     "& EOLICA-HISTORICO-VENTO-HORIZONTE ; DataInicial ; DataFinal\n",
     "EOLICA-HISTORICO-VENTO-HORIZONTE ; 1979/01 ; 2016/01\n",
