@@ -10,16 +10,16 @@ def test_atributos_encontrados_coper():
     m: MagicMock = mock_open(read_data="".join(MockCoper))
     with patch("builtins.open", m):
         n = Coper.le_arquivo("")
-        assert n.custos is not None
-        assert n.custos.iloc[0, 0] == 2022
-        assert n.custos.iloc[-1, -1] == 1155.67
+        assert n.valores is not None
+        assert n.valores.iloc[0, 0] == 2022
+        assert n.valores.iloc[-1, -1] == 1155.67
 
 
 def test_atributos_nao_encontrados_coper():
     m: MagicMock = mock_open(read_data="")
     with patch("builtins.open", m):
         n = Coper.le_arquivo("")
-        assert n.custos is None
+        assert n.valores is None
 
 
 def test_eq_coper():
