@@ -12,9 +12,9 @@ def test_atributos_encontrados_geolm():
         n = Geolm.le_arquivo("")
         assert n.submercado is not None
         assert n.submercado == "NORDESTE"
-        assert n.geracao is not None
-        assert n.geracao.iloc[0, 0] == 2021
-        assert n.geracao.iloc[-1, -1] == 5850.4
+        assert n.valores is not None
+        assert n.valores.iloc[0, 0] == 2021
+        assert n.valores.iloc[-1, -1] == 5850.4
 
 
 def test_atributos_nao_encontrados_geolm():
@@ -22,7 +22,7 @@ def test_atributos_nao_encontrados_geolm():
     with patch("builtins.open", m):
         n = Geolm.le_arquivo("")
         assert n.submercado is None
-        assert n.geracao is None
+        assert n.valores is None
 
 
 def test_eq_geolm():
